/* Sphinx themes
-------------------------------------------------- */

body {
  background-color: #edf0f2;
  margin: 0;
  padding: 0;
  font-family: "Open Sans", Helvetica, Arial, sans-serif;
  font-size: 16px;
  color: #333;
  line-height: 1.5;
}

#left-column {
  float: left;
  position: fixed;
  height: 100%;
  border-right: 1px solid #e0e0e0;
  width: 300px;
  overflow: auto;
  background: #fafafa;
}

#right-column {
  padding: 20px 0;
  margin-left: 300px;
  background-color: #fff;
  max-width: 900px;
}

a.headerlink {
  visibility: hidden;
  color: #ddd;
  padding: 0 4px;
  text-decoration: none;
}

h1:hover > a.headerlink,
h2:hover > a.headerlink,
h3:hover > a.headerlink,
h4:hover > a.headerlink,
h5:hover > a.headerlink,
h6:hover > a.headerlink,
dt:hover > a.headerlink {
  visibility: visible;
}

h1 > a, h2 > a, h3 > a, h4 > a, h5 > a, h6 > a {
  color: #5C7C98;
}

h1, h2, h3, h4, h5, h6 {
  color: black;
  font-weight: normal;
  padding: 0;
  font-family: "Source Serif Pro", "serif";
}

h1, h2, h3 {
  margin-top: 30px;
  margin-bottom: 20px;
}

h1 {
  font-size: 38px;
  padding: 10px 10px 10px 45px;
  margin: 20px 0 35px -45px;
  background-color: aliceblue;
  width: calc(100% + 90px);
  border-bottom: 1px solid #D8E4EF;
}

h2 {
  font-size: 34px;
  padding: .2em 0;
  border-bottom: 1px solid #ddd;
}

h3 {
  margin-top: 35px;
  font-size: 28px;
}

h4 {
  margin-top: 30px;
  font-size: 24px;
}

h5 {
  margin-top: 25px;
  font-size: 20px;
}

div.clearer {
  clear: both;
}

.container-wrapper {
  padding: 0;
  position: relative;
}

div.related {
  display: none;
}

p {
  padding: 0;
  font-family: inherit;
  font-size: inherit;
  color: #333;
}

code, pre, tt {
  font-size: 15px;
  font-family: Consolas, monospace;
}

code, tt {
  color: #8D1A38;
}

tt {
  padding: 0 2px;
}

code, pre {
  line-height: 23px;
  margin: 20px 0;
  word-wrap: normal;
  background-color: #fff;
}

pre {
  color: #333;
  background-color: #fff;
  overflow: auto;
  border-width: 0 0 0 2px;
  border-color: #eee;
  border-style: solid;
  padding: 14px 0 14px 20px;
  padding-right: 0;
  margin: 20px 0;
}

div.highlight {
  background-color: white;
}

a.internal em {
  font-style: normal;
}

dl dd {
  margin: 3px 0 10px 30px;
}

dl.method {
  border-bottom: 1px solid #ccc;
}

.breadcrumb {
  font-size: 15px;
  margin-bottom: 12px;
  background: #fff;
}

blockquote {
  border-width: .1em 0 .1em 0;
  border-color: #e5eef2;
  border-style: solid;
  background-color: #f3f8f9;
  color: #000;
  margin: 20px 0;
  padding: 15px 20px;
  font-size: 16px;
}

/* Sphinx sidebar
-------------------------------------------------- */

div.sphinxsidebar {
  word-wrap: break-word;
}

div.sphinxsidebar .panel-default > .panel-heading {
    background-image: none;
}

.sidebar-wrapper {
  padding: 0 22px;
}

div.sphinxsidebar h3,
div.sphinxsidebar h4 {
  color: #444;
  font-size: 20px;
  font-weight: normal;
  margin: 0;
  padding: 0;
}

div.sphinxsidebar h4 {
  font-size: 16px;
}

div.sphinxsidebar p {
  color: #555;
  margin: 10px 0;
}

.sidebar-toc {
  font-size: 15px;
}

div.sphinxsidebar .sidebar-toc ul {
  margin: 0 0 4px 0;
  list-style-type: none;
  color: #000;
}

div.sphinxsidebar .sidebar-toc a {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  color: #444;
  text-decoration: none;
}

.sidebar-toc > ul {
    padding: 0 !important;
    list-style-type: none;
    margin: 0;
}

.sidebar-toc ul li a {
  display: block;
}

.sidebar-toc ul li a:hover {
  background-color: #428bca;
  color: #fff;
}

.sidebar-toc ul li.current > a,
.sidebar-toc ul li.current > a:hover {
  background-color: #e6e6e6;
  color: #444;
}

.sidebar-toc ul li.toctree-l1 a {
  padding: 5px 25px;
}

.sidebar-toc ul li.toctree-l2 a {
  padding: 5px 50px;
}

.sidebar-toc ul li.toctree-l3 a {
  padding: 5px 75px;
}

div.sphinxsidebar ul.want-points {
  padding-left: 20px;
  margin: 0;
}

div.sphinxsidebar .sidebar-toc ul ul {
  margin: 0;
  padding: 0;
}

.sidebar-localtoc ul {
    padding-left: 24px;
}

div.sphinxsidebar input {
  border: 1px solid #ccc;
  font-family: Helvetica, arial, freesans, clean, sans-serif;
  font-size: 1em;
}

.margin-top-1em {
  margin-top: 1em;
}

.sidebar-block {
  padding: 0;
  margin: 14px 0 30px 0;
}

.sidebar-block h2 {
  border-bottom: none;
  margin: 0 0 17px 0;
  font-size: 14px;
  font-family: "Open Sans", Helvetica, Arial, sans-serif;
  padding: 0 0 6px 0;
  font-weight: bold;
  text-transform: uppercase;
  color: #606060;
}

.sidebar-block .bd {
  font-size: 16px;
}

.sphinxsidebar > .sidebar-block:not(:last-child):after {
    content: '';
    display:block;
    border-top: 1px solid #ccc;
    margin: 24px 22px 0 22px;
}

.text-logo {
  font-size: 18px;
  text-align: center;
  display: block;
  padding: 8px;
  color: #fff;
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  margin: 0 0 20px 0;
  font-weight: bold;
  background-color: #337ab7;
  border-bottom: 1px solid #fff;
}

.text-logo:hover {
  color: #fff;
}

/* Left-nav search box
-------------------------------------------------- */

#main-search form .input-group {
  width: 100%;
  margin: 0 0 12px 0;
  padding: 0;
  border: none;
}

#main-search form .input-group input {
  padding: 4px;
  width: 100%;
  border-radius: 5px;
  margin: 0;
  font-size: 15px;
}

.search-page-form {
  width: 350px;
}

/* Two-pane table list
-------------------------------------------------- */

.table-bordered>thead>tr>th,
.table-bordered>tbody>tr>th,
.table-bordered>tfoot>tr>th,
.table-bordered>thead>tr>td,
.table-bordered>tbody>tr>td,
.table-bordered>tfoot>tr>td,
table.two-column.table-bordered caption+thead tr:first-child th:first-child,
table.two-column.table-bordered caption+tbody tr:first-child td:first-child,
table.two-column.table-bordered colgroup+thead tr:first-child th:first-child,
table.two-column.table-bordered colgroup+tbody tr:first-child td:first-child,
table.two-column tbody td
  border: 0 0 1px 0 solid #eee;
  border-left: none;
  padding: 8px 4px;
  font-size: 16px;
}

table.two-column {
  width: 100%;
  border: 0px none !important;
  box-shadow: none;
}

/* Disqus comments styles
-------------------------------------------------- */

.comment-container {
  margin: 24px auto;
}

/* Next and previous links
-------------------------------------------------- */

.footer-relations {
  display: relative;
  border-top: 1px solid #ccc;
  padding: 12px 45px;
  margin-top: 30px;
  font-size: 24px;
}

.rel-spacer {
  height: 40px;
}

/* Footer styling
-------------------------------------------------- */

div.footer {
  padding: 25px;
  font-size: 14px;
  color: #888;
  text-align: right;
  max-width: 1200px;
  width: 100%;
}

div.footer a {
  color: #888;
}

/* -- relbar ---------------------------------------------------------------- */

div.related {
  width: 100%;
  font-size: 90%;
}

div.related h3 {
  display: none;
}

div.related ul {
  margin: 0;
  padding: 0 0 0 10px;
  list-style: none;
}

div.related li {
  display: inline;
}

div.related li.right {
  float: right;
  margin-right: 5px;
}

/* -- search page ----------------------------------------------------------- */

ul.search {
  margin: 10px 0 0 20px;
  padding: 0;
}

ul.search li {
  padding: 5px 0 5px 20px;
  background: url(file.png) no-repeat 0 7px;
}

ul.search li a {
  font-weight: bold;
}

ul.search li div.context {
  color: #888;
  margin: 2px 0 0 30px;
  text-align: left;
}

ul.keywordmatches li.goodmatch a {
  font-weight: bold;
}

/* -- general index --------------------------------------------------------- */

table {
  margin-bottom: 20px;
}

table.indextable {
  width: 100%;
}

table.indextable td {
  text-align: left;
  vertical-align: top;
}

table.indextable dl, table.indextable dd {
  margin-top: 0;
  margin-bottom: 0;
}

table.indextable tr.pcap {
  height: 10px;
}

table.indextable tr.cap {
  margin-top: 10px;
  background-color: #f2f2f2;
}

img.toggler {
  margin-right: 3px;
  margin-top: 3px;
  cursor: pointer;
}

div.modindex-jumpbox {
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  margin: 1em 0 1em 0;
  padding: 0.4em;
}

div.genindex-jumpbox {
  border-top: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  margin: 1em 0 1em 0;
  padding: 0.4em;
}

/* -- general body styles --------------------------------------------------- */

.body {
  padding: 0 45px;
}

div.body p.caption {
  text-align: inherit;
}

table.field-list {
  border: 1px solid #ddd;
  border-collapse: collapse;
  border-spacing: 0;
  width: 100%;
}

table.field-list td,
table.field-list th {
  border: 1px solid #ddd;
  padding: 8px;
  vertical-align: top;
  line-height: 1.4;
}

.field-list ul {
  padding-left: 1em;
}

.first {
  margin-top: 0 !important;
}

p.rubric {
  margin-top: 30px;
  font-weight: bold;
}

img.align-left, .figure.align-left, object.align-left {
  clear: left;
  float: left;
  margin-right: 1em;
}

img.align-right, .figure.align-right, object.align-right {
  clear: right;
  float: right;
  margin-left: 1em;
}

img.align-center, .figure.align-center, object.align-center {
  display: block;
  margin-left: auto;
  margin-right: auto;
}

.align-left {
  text-align: left;
}

.align-center {
  text-align: center;
}

.align-right {
  text-align: right;
}

/* -- topics ---------------------------------------------------------------- */

div.topic {
  border: 1px solid #e8e8e8;
  padding: 7px 7px 0 7px;
  margin: 10px 0 10px 0;
  background-color: #f8f8f8;
}

p.topic-title {
  font-size: 1.1em;
  font-weight: bold;
  margin-top: 10px;
}

/* -- contents-------------------------------------------------------------- */

div.topic.contents {
    display: inline-block;
    border-radius: 3px;
    padding: 24px 36px 18px 36px;
}

div.topic.contents > ul {
    padding-left: 20px;
}

/* -- admonitions ----------------------------------------------------------- */

.admonition {
  margin: 20px 0;
  padding: 20px;
  background-color: #fff;
  border: 1px solid #eee;
  border-left-width: 6px;
  border-radius: 3px;
}

.admonition dt {
  font-weight: bold;
}

.admonition dl {
  margin-bottom: 0;
}

.admonition-title {
  margin: 0px 0 5px;
  padding: 0;
  font-weight: bold;
  font-size: 18px;
  line-height: 1.1;
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
}

.admonition.danger,
.admonition.error {
  border-left-color: #d9534f;
}

.admonition.danger .admonition-title,
.admonition.error .admonition-title {
  color: #d9534f;
}

.admonition.important,
.admonition.warning,
.admonition.attention,
.admonition.caution {
  border-left-color: #f0ad4e;
}

.admonition.important .admonition-title,
.admonition.warning .admonition-title,
.admonition.attention .admonition-title,
.admonition.caution .admonition-title {
  color: #9B581F;
}

.admonition.note,
.admonition.hint {
  border-left-color: #31708f;
}

.admonition.note .admonition-title,
.admonition.hint .admonition-title {
  color: #31708f;
}

.admonition.tip {
  border-left-color: #3c763d;
}

.admonition.tip .admonition-title {
  color: #3c763d;
}

div.body p.centered {
  text-align: center;
  margin-top: 25px;
}

div.seealso {
  background-color: #ffc;
  border: 1px solid #ff6;
}

div.admonition tt.xref, div.admonition a tt {
  border-bottom: 1px solid #fafafa;
}

div.admonition p.last {
  margin-bottom: 0;
}

/* -- other body styles ----------------------------------------------------- */

ol.arabic {
  list-style: decimal;
}

ol.loweralpha {
  list-style: lower-alpha;
}

ol.upperalpha {
  list-style: upper-alpha;
}

ol.lowerroman {
  list-style: lower-roman;
}

ol.upperroman {
  list-style: upper-roman;
}

.highlighted {
  background-color: #fbe54e;
}

dl.glossary dt {
  font-weight: bold;
  font-size: 1.1em;
}

.field-list ul {
  margin: 0;
  padding-left: 1em;
}

.refcount {
  color: #060;
}

.optional {
  font-size: 1.3em;
}

.versionmodified {
  font-style: italic;
}

.system-message {
  background-color: #fda;
  padding: 5px;
  border: 3px solid red;
}

.footnote:target  {
  background-color: #ffa;
}

.line-block {
  display: block;
  margin-top: 1em;
  margin-bottom: 1em;
}

.line-block .line-block {
  margin-top: 0;
  margin-bottom: 0;
  margin-left: 1.5em;
}

.guilabel, .menuselection {
  font-family: sans-serif;
}

.accelerator {
  text-decoration: underline;
}

.classifier {
  font-style: oblique;
}

abbr, acronym {
  border-bottom: dotted 1px;
  cursor: help;
}

dt:target, .highlight {
  background: #FAF3E8;
}

/* -- code displays --------------------------------------------------------- */

td.linenos pre {
  padding: 5px 0px;
  border: 0;
  background-color: transparent;
  color: #aaa;
}

table.highlighttable {
  margin-left: 0.5em;
}

table.highlighttable td {
  padding: 0 0.5em 0 0.5em;
}

tt.descname {
  background-color: transparent;
  font-weight: bold;
  padding-right: 0.08em;
}

tt.descclassname {
  background-color: transparent;
}

tt.descname, tt.descclassname {
  font-size: 0.95em;
}

tt.xref, a tt {
  background-color: transparent;
  font-weight: bold;
}

h1 tt, h2 tt, h3 tt, h4 tt, h5 tt, h6 tt {
  background-color: transparent;
}

.viewcode-link {
  float: right;
}

.viewcode-back {
  float: right;
  font-family: sans-serif;
}

div.viewcode-block:target {
  margin: -1px -10px;
  padding: 0 10px;
}

/* -- math display ---------------------------------------------------------- */

img.math {
  vertical-align: middle;
}

div.body div.math p {
  text-align: center;
}

span.eqno {
  float: right;
}

/* -- Theme specific classes - */

.overflow-height-500px {
  overflow: auto;
  height: 500px;
}

.overflow-height-250px {
  overflow: auto;
  height: 250px;
}

/* Toggle mobile view
-------------------------------------------------- */

#mobile-toggle {
  height: 40px;
  width: 100%;
  display: none;
  padding: 12px;
  border-bottom: 1px solid #ccc;
  position: fixed;
  top: 0;
  left: 0;
  background-color: #fff;
  z-index: 1;
}

/* Small screen styles
-------------------------------------------------- */

@media screen and (max-width: 768px) {

  body {
    padding: 0px;
    margin: 0px;
    background-color: #fff;
  }

  h1 {
    margin-left: 0;
    width: 100%;
    padding: 10px;
    font-size: 40px;
  }

  #left-column {
    position: relative;
    top: 0;
    left: 0;
    display: none;
    width: 100%;
    float: none;
    margin: 40px 0 0 0;
  }

  .footer-relations {
    padding: 12px 0;
  }

  #right-column {
    margin-left: 0;
    margin-top: 0;
    padding: 50px 20px 8px 20px;
    width: 100%;
    float: none;
  }

  .document {
    position: relative;
    padding: 0;
    width: 100%
  }

  .body {
    padding: 0px;
  }

  #mobile-toggle {
    display: block;
  }

  p {
    padding: 0;
  }
}

/* Account for when the left column is closed then page is expanded.
-------------------------------------------------- */

@media screen and (min-width: 769px) {
  #left-column {
    display: block !important;
  }
}

/* Syntax highlighting
-------------------------------------------------- */

.hll { background-color: #ffffcc }
.c { color: #999988; font-style: italic } /* Comment */
.err { color: #a61717; background-color: #e3d2d2 } /* Error */
.k { color: #000000; font-weight: bold } /* Keyword */
.o { color: #000000; font-weight: bold } /* Operator */
.cm { color: #999988; font-style: italic } /* Comment.Multiline */
.cp { color: #999999; font-weight: bold; font-style: italic } /* Comment.Preproc */
.c1 { color: #999988; font-style: italic } /* Comment.Single */
.cs { color: #999999; font-weight: bold; font-style: italic } /* Comment.Special */
.gd { color: #000000; background-color: #ffdddd } /* Generic.Deleted */
.ge { color: #000000; font-style: italic } /* Generic.Emph */
.gr { color: #aa0000 } /* Generic.Error */
.gh { color: #999999 } /* Generic.Heading */
.gi { color: #000000; background-color: #ddffdd } /* Generic.Inserted */
.go { color: #888888 } /* Generic.Output */
.gp { color: #555555 } /* Generic.Prompt */
.gs { font-weight: bold } /* Generic.Strong */
.gu { color: #aaaaaa } /* Generic.Subheading */
.gt { color: #aa0000 } /* Generic.Traceback */
.kc { color: #000000; font-weight: bold } /* Keyword.Constant */
.kd { color: #000000; font-weight: bold } /* Keyword.Declaration */
.kn { color: #000000; font-weight: bold } /* Keyword.Namespace */
.kp { color: #000000; font-weight: bold } /* Keyword.Pseudo */
.kr { color: #000000; font-weight: bold } /* Keyword.Reserved */
.kt { color: #445588; font-weight: bold } /* Keyword.Type */
.m { color: #009999 } /* Literal.Number */
.s { color: #d01040 } /* Literal.String */
.na { color: #008080 } /* Name.Attribute */
.nb { color: #0086B3 } /* Name.Builtin */
.nc { color: #445588; font-weight: bold } /* Name.Class */
.no { color: #008080 } /* Name.Constant */
.nd { color: #3c5d5d; font-weight: bold } /* Name.Decorator */
.ni { color: #800080 } /* Name.Entity */
.ne { color: #990000; font-weight: bold } /* Name.Exception */
.nf { color: #990000; font-weight: bold } /* Name.Function */
.nl { color: #990000; font-weight: bold } /* Name.Label */
.nn { color: #555555 } /* Name.Namespace */
.nt { color: #000080 } /* Name.Tag */
.nv { color: #008080 } /* Name.Variable */
.ow { color: #000000; font-weight: bold } /* Operator.Word */
.w { color: #bbbbbb } /* Text.Whitespace */
.mf { color: #009999 } /* Literal.Number.Float */
.mh { color: #009999 } /* Literal.Number.Hex */
.mi { color: #009999 } /* Literal.Number.Integer */
.mo { color: #009999 } /* Literal.Number.Oct */
.sb { color: #d01040 } /* Literal.String.Backtick */
.sc { color: #d01040 } /* Literal.String.Char */
.sd { color: #d01040 } /* Literal.String.Doc */
.s2 { color: #d01040 } /* Literal.String.Double */
.se { color: #d01040 } /* Literal.String.Escape */
.sh { color: #d01040 } /* Literal.String.Heredoc */
.si { color: #d01040 } /* Literal.String.Interpol */
.sx { color: #d01040 } /* Literal.String.Other */
.sr { color: #009926 } /* Literal.String.Regex */
.s1 { color: #d01040 } /* Literal.String.Single */
.ss { color: #990073 } /* Literal.String.Symbol */
.bp { color: #999999 } /* Name.Builtin.Pseudo */
.vc { color: #008080 } /* Name.Variable.Class */
.vg { color: #008080 } /* Name.Variable.Global */
.vi { color: #008080 } /* Name.Variable.Instance */
.il { color: #009999 } /* Literal.Number.Integer.Long */