/*****************************************************
 * p_sphinx_theme.css_t
 * ~~~~~~~~~~~~~~~~~~~~
 *
 * adjusted from stylesheet for "Cloud" theme for Sphinx.
 *
 * :copyright: Copyright 2011-2012 by Assurance Technologies
 * :license: BSD
 *
 *****************************************************/

@import url("basic.css");





   
   




















/*****************************************************
 * page layout - body
 *****************************************************/

* {
   box-sizing: border-box;
   -moz-box-sizing: border-box;
   -webkit-box-sizing: border-box;
}

body
{
   margin: 1em 1em 0 1em;
   padding: 0;
   background: #1A4162;
   background-attachment: fixed;
   color: #000;
   font-family: "Noto Sans";
   font-size: 100%;
   line-height: 1em;
}

/*****************************************************
 * page layout - relbars (top & bottom)
 *****************************************************/

div.related
{
   margin: 0 auto;
   max-width: 14in;
   background: #5682AD;
   line-height: 1.5em;
   padding: .75em 0;
   color: #ffffff;
   text-shadow: 1px 1px 1px rgba(0,0,0,.3);
}

div.relbar-top div.related
{
   
   -moz-border-radius: .7em .7em 0 0;
   -webkit-border-radius: .7em .7em 0 0;
   -o-border-radius: .7em .7em 0 0;
   -ms-border-radius: .7em .7em 0 0;
   border-radius: .7em .7em 0 0;


}

div.relbar-bottom div.related
{
   
   -moz-border-radius: 0 0 .7em .7em;
   -webkit-border-radius: 0 0 .7em .7em;
   -o-border-radius: 0 0 .7em .7em;
   -ms-border-radius: 0 0 .7em .7em;
   border-radius: 0 0 .7em .7em;


}

div.related a
{
   display: inline-block;
   padding: 0.3em 0.6em;
   
   -moz-border-radius: 0.5em;
   -webkit-border-radius: 0.5em;
   -o-border-radius: 0.5em;
   -ms-border-radius: 0.5em;
   border-radius: 0.5em;


   font-weight: bold;
   color: #ffffff;
}

div.related li.right a
{
   background: rgba(0,0,0,.1);
   font-weight: normal;
}

div.related a:hover,
div.related li.right a:hover
{
   background: rgba(0,0,0,.2);
   text-decoration: none;
}

/*****************************************************
 * page layout - document
 *****************************************************/

div.document
{
   /* note: relative used by div.sidebartoggle */
   position: relative;
   margin: 0 auto;
   max-width: 14in;
   background: #F2F2F2;
}

div.documentwrapper
{
   float: left;
   width: 100%;
}

div.bodywrapper
{
   margin: 0 0 0 230px;
 
}


div.document.collapsed-sidebar div.bodywrapper { margin-left: 0; }


div.body
{
   min-height: 6in;
   /* note: this ^ is just a hack to prevent body from being shorter than sidebar */

   background-color: #ffffff;
   border-left: 1px solid rgba(0,0,0,.12);

   line-height: 1.5em;

   color: #000000;
   padding: 30px 20px;
}

/*****************************************************
 * page layout - sidebar
 *****************************************************/

div.sphinxsidebar
{
   /* it's nasty sometimes, but looks prettier than letting too-long module names break into document body*/
   overflow: hidden;

   width: 230px;

   font-size: 90%;
   line-height: 1.25em;
}


   div.sphinxsidebar:hover
   {
      overflow: visible;
   }



   div.document.collapsed-sidebar div.sphinxsidebar { display: none; }


div.sphinxsidebarwrapper
{
   padding: 1em 0 0 10px;
}

div.sphinxsidebar h3,
div.sphinxsidebar h4
{
   padding: 0;
   margin: 24px 16px 0 0;

   font-family: "Noto Serif";
   font-weight: normal;
   color: #777777;
}

div.sphinxsidebar h3 { font-size: 1.4em; }
div.sphinxsidebar h4 { font-size: 1.3em; }

div.sphinxsidebar h3 a,
div.sphinxsidebar h4 a
{
   color: #777777;
}

div.sphinxsidebar p
{
   color: #777777;
}

div.sphinxsidebar p.topless
{
   margin: 5px 10px 10px 10px;
}

div.sphinxsidebar ul
{
   margin: 10px;
   margin-right: 0;
   padding: 0;
   color: #777777;
}

div.sphinxsidebar a
{
   color: #003469;
   outline: none;
}

div.sphinxsidebar a:active
{
   color: #777777;
}

div.sphinxsidebar p.logo
{
   margin: 1em 0 0 -10px;
   text-align: center;
}

/* fix margin if h3/h4 is at top of sidebar --
 * consequence of sidebar boxes not all being wrapped in divs.
 */
div.sphinxsidebarwrapper > h3:first-child,
div.sphinxsidebarwrapper > h4:first-child,
div.sphinxsidebarwrapper > div:first-child > h3:first-child,
div.sphinxsidebarwrapper > div:first-child > h4:first-child
{
   margin-top: .2em;
}

/*****************************************************
 * page layout - sidebar TOC sections
 *****************************************************/


div.sphinxlocaltoc,
div.sphinxglobaltoc
{
   display: inline-block; 
   background: #F2F2F2;
   border-right: 1px solid rgba(0,0,0,.12);
   padding-right: 0.8em;
   min-width: 100%;
   overflow: hidden;
   position: relative;
   left: 1px; 
   
   -moz-border-radius: 0 0.7em 0.7em 0;
   -webkit-border-radius: 0 0.7em 0.7em 0;
   -o-border-radius: 0 0.7em 0.7em 0;
   -ms-border-radius: 0 0.7em 0.7em 0;
   border-radius: 0 0.7em 0.7em 0;



}


div.sphinxlocaltoc ul a,
div.sphinxglobaltoc ul a
{
   display: block;
   padding: 0 .2em;
   margin: 0 -.2em;
   
      white-space: nowrap;
   
}

div.sphinxlocaltoc ul a.visible,
div.sphinxglobaltoc ul a.visible
{
   background: #FFF8E4;
   
   -moz-box-shadow: 0 .1em .5em #FFF8E4;
   -webkit-box-shadow: 0 .1em .5em #FFF8E4;
   -o-box-shadow: 0 .1em .5em #FFF8E4;
   -ms-box-shadow: 0 .1em .5em #FFF8E4;
   box-shadow: 0 .1em .5em #FFF8E4;


}

/*****************************************************
 * page layout - sidebar searchbox & search page
 *****************************************************/

div.sphinxsidebar input,
h1#search-documentation ~ form > input
{
   border: 1px solid rgba(0,0,0,.2);
   font-family: sans-serif;
   font-size: 1em;
}

div#searchbox input[type="submit"],
h1#search-documentation ~ form > input[type="submit"]
{
   background: #F2F2F2;
   
   -moz-border-radius: 0 0 0.7em 0;
   -webkit-border-radius: 0 0 0.7em 0;
   -o-border-radius: 0 0 0.7em 0;
   -ms-border-radius: 0 0 0.7em 0;
   border-radius: 0 0 0.7em 0;


}

div#searchbox input[type="submit"]:hover,
h1#search-documentation ~ form > input[type="submit"]:hover,
div.sidebartoggle button:hover
{
   background: rgba(255,0,0,.2);
}

div.sphinxsidebar .searchtip
{
   color: #999999;
}

/*****************************************************
 * page layout - collapsible sidebar buttons
 *****************************************************/


div.sidebartoggle
{
   position: absolute;
   width: 230px;
   top: 0;
   left: 0;
   z-index: 1;
}

div.document.collapsed-sidebar div.sidebartoggle
{
 width: auto;
}

div.sidebartoggle button
{
   position: absolute;
   right: -1px;
   top: 0;

   margin: 0;
   padding: 0 6px;

   background: #F2F2F2;
   border: 1px solid rgba(0,0,0,.2);
   border-width: 0 1px 1px 1px;
   color: #777777;
      
   -moz-border-radius: 0 0 0 0.7em;
   -webkit-border-radius: 0 0 0 0.7em;
   -o-border-radius: 0 0 0 0.7em;
   -ms-border-radius: 0 0 0 0.7em;
   border-radius: 0 0 0 0.7em;


   

   white-space: nowrap;
}

div.document.collapsed-sidebar div.sidebartoggle button
{
   left: 0;
   right: auto;
      
   -moz-border-radius: 0 0 0.7em 0;
   -webkit-border-radius: 0 0 0.7em 0;
   -o-border-radius: 0 0 0.7em 0;
   -ms-border-radius: 0 0 0.7em 0;
   border-radius: 0 0 0.7em 0;


   
}



/*****************************************************
 * page layout - footer
 *****************************************************/

div.footer
{
   color: #B0B0B0;
   width: 100%;
   padding: 9px 0;
   text-align: center;
   font-size: 75%;
}

div.footer button.link
{
 margin: 0 -1px;
 padding: 0;
 background: none;
 border: none;
 font-size: inherit;
 font-family: inherit;
}

div.footer a,
div.footer button.link
{
   color: #B0B0B0;
   text-decoration: underline;
}

div.footer a:hover,
div.footer button.link:hover
{
    color: white;
}

div.footer + div.footer,
div.footer + script + div.footer
{
   margin-top: -12px;
}

/*****************************************************
 * document - section headers
 *****************************************************/

div.body h1,
div.body h2,
div.body p.rubric,
div.body h3,
div.body h4,
div.body h5,
div.body h6
{
   margin: 1em 0 -.25em 0;
   padding: 0;

   color: #000000;
/*
   
      text-shadow: 1px 1px 1px ;
   
*/

   font-family: "Noto Serif";
   font-weight: normal;
   line-height: 1.5em;
}

div.body h1 {
   margin: .5em 0;
   text-align: center;
   font-size: 200%;
/*
   
*/
}

div.body h2, div.body p.rubric { font-size: 160%; }
div.body h3 { font-size: 140%; }
div.body h4 { font-size: 120%; }
div.body h5 { font-size: 110%; }
div.body h6 { font-size: 100%; }

#table-of-contents > h1, /* hack for toc page */
h1#search-documentation, /* hack for search page */
div.body h2,
div.body p.rubric,
/* div.section.emphasized > h3,  deprecated in favor of below: */
div.section.emphasize-children > div.section > h3
{
   margin: 1em -10px 0;
   padding: 12px 10px 10px;
   clear: both; /* for floating admonitions */
   border-style: solid;
   border-color: rgba(0,0,0,.125);
      background: #84A6C7;
      border-top-width: 0px;
      border-right-width: 1px;
      border-bottom-width: 1px;
      border-left-width: 0px;

      font-style: italic;
      
   -moz-border-radius: 10px;
   -webkit-border-radius: 10px;
   -o-border-radius: 10px;
   -ms-border-radius: 10px;
   border-radius: 10px;


      color: #ffffff;
   
}

#table-of-contents > h1, /* hack for toc page */
h1#search-documentation /* hack for search page */
{
   margin-top: 0;
}

div.body h2.highlighted,
 /*div.section.emphasized > h3.highlighted, deprecated in favor of below: */
div.section.emphasize-children > div.section > h3.highlighted
{
   border: 0.25em solid #fbe54e;
}

div#search-results > h2, /* hack for search page */
div.body p.rubric,
/*div.section.emphasized > h3,  deprecated in favor of below: */
div.section.emphasize-children > div.section > h3
{
   
      background: #92BCDE;
   
}

/*div.section.emphasized > h3,  deprecated in favor of below: */
div.section.emphasize-children > div.section > h3
{
   margin-left: 0;
   margin-right: 0;
}

a.headerlink
{
   color: #003469;
   font-size: 0.8em;
   margin: 0 0 0 1px;
   padding: 0 5px 0 4px;
   text-decoration: none;
   
   -moz-border-radius: 5px;
   -webkit-border-radius: 5px;
   -o-border-radius: 5px;
   -ms-border-radius: 5px;
   border-radius: 5px;


}

a.headerlink:hover
{
   background-color: #003469;
   color: white;

   
   -moz-box-shadow: 2px 2px 2px rgba(0,0,0,.2);
   -webkit-box-shadow: 2px 2px 2px rgba(0,0,0,.2);
   -o-box-shadow: 2px 2px 2px rgba(0,0,0,.2);
   -ms-box-shadow: 2px 2px 2px rgba(0,0,0,.2);
   box-shadow: 2px 2px 2px rgba(0,0,0,.2);


}

/*****************************************************
 * document - toggleable sections
 *****************************************************/

.html-toggle-button
{
   position: relative;
}

.html-toggle-button:hover
{
   /* give a little bit of hint that this is clickable */
   cursor: pointer;

   
      background: #003469;
      
   -moz-box-shadow: 2px 2px 2px #003469;
   -webkit-box-shadow: 2px 2px 2px #003469;
   -o-box-shadow: 2px 2px 2px #003469;
   -ms-box-shadow: 2px 2px 2px #003469;
   box-shadow: 2px 2px 2px #003469;


   
}

div.body div.section:not(.emphasize-children) > div.section:not(.emphasized) > h3.html-toggle-button:hover,
div.body h4.html-toggle-button:hover
{
   background: #92BCDE;
   
   -moz-box-shadow: 0 0 2px #003469;
   -webkit-box-shadow: 0 0 2px #003469;
   -o-box-shadow: 0 0 2px #003469;
   -ms-box-shadow: 0 0 2px #003469;
   box-shadow: 0 0 2px #003469;


}

.html-toggle.collapsed > .html-toggle-button
{
   margin-bottom: 1em;
}

.html-toggle.collapsed > .html-toggle-button:after
{
   content: "[+ show section]";
   margin: 0;
   padding: .15em 0 0 0;
   text-shadow: none;
   color: inherit;
   font-size: 65%;
   font-style: italic;
   font-weight: bold;
}

.html-toggle.expanded > .html-toggle-button:after
{
   content: "[- hide section]";
   margin: 0;
   padding: .15em 0 0 0;
   text-shadow: none;
   color: inherit;
   font-size: 65%;
   font-style: italic;
   font-weight: bold;
}

.html-toggle-button:hover a.headerlink:not(:hover) { filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0);
 opacity: 0;
 }

/*****************************************************
 * document - misc styles
 *****************************************************/

div.body p,
div.body dd,
div.body li
{
   text-align: justify;
   line-height: 1.5em;
}

div.body hr {
   margin: 0 10px;
   background: none;
   border: 1px dashed rgba(0,0,0,.2);
   border-width: 1px 0 0 0;
}

   /*------------------------------------
    * footnotes
    *------------------------------------*/

a.footnote-reference
{
   font-size: 70%;
   position: relative;
   top: -.75em;
}

table.docutils.footnote { margin: 1em 0 0 1em; }

   /*------------------------------------
    * lists (UL, OL, DL)
    *------------------------------------*/

dl { margin-bottom: 1.5em; }
li > dl:only-child { margin-bottom: 0; }

dd ol { margin-bottom: 10px; }

dl.docutils > dt { font-size: 1.1em; margin-bottom: .5em; }
dl.docutils > dd + dt { margin-top: 1.5em; }

/* join separate ULs together */
ul + ul,
ul + div > ul:only-child,
div.toctree-wrapper + ul { margin-top: -1em; }

/*****************************************************
 * document - links
 *****************************************************/

a
{
   color: #003469;
   text-decoration: none;
}

a:visited
{
   
   text-decoration: none;
}

a:hover
{
   text-decoration: underline;
}

a.biglink
{
   font-size: 130%;
}


a.external:before
{
   content: "\21D7";
   padding-right: .1em;
}

a.external.issue:before
{
   content: "\2727";
}

a.external[href^="mailto:"]:before
{
   content: "";
}

em.issue:before
{
   content: "\2727";
   padding-right: .1em;
}


dt:target,
.footnote:target,
.highlighted
{
   padding: 4px;
   margin: -4px;

   background-color: #fbe54e;

    
   -moz-border-radius: 4px;
   -webkit-border-radius: 4px;
   -o-border-radius: 4px;
   -ms-border-radius: 4px;
   border-radius: 4px;


}

/*****************************************************
 * document - table styles
 *****************************************************/

   /*------------------------------------
    * custom table classes
    *------------------------------------*/

table.fullwidth { width: 100%; }

table.centered { margin-left: auto; margin-right: auto; }

table.docutils.plain { border: none; }
table.docutils.plain tr.row-odd > * { background: none; }

/* legacy alias for table.plain */
table.docutils.html-plain-table tr.row-odd > * { background: none; }

   /*------------------------------------
    * default table styling
    *------------------------------------*/

table.docutils th {
   border: 0 solid transparent;
   padding: .4em;
   font-family: "Noto Serif";
   background: rgba(0,0,0,.15);
}

table.docutils th.head:not(.stub) {
   border-bottom: 1px solid rgba(0,0,0,.15);
}

table.docutils th.stub + td
{
   border-left: 1px solid rgba(0,0,0,.15);
}

table.docutils td {
   padding: .4em;
   border: 0 solid rgba(0,0,0,.15);
}
table.docutils tr.row-odd td { background: rgba(0,0,0,.06); }

h2 + table.docutils { margin-top: 1em; }
table > caption { margin: 1em 0 .5em; font-style: italic; }

   /*------------------------------------
    * td/th classes added by .ext.table_styling
    *------------------------------------*/
table.docutils .left-align { text-align: left; }
table.docutils .center-align { text-align: center; }
table.docutils .right-align { text-align: right; }
table.docutils .justify-align { text-align: justify; }
table.docutils .nowrap { white-space: nowrap; }

table.docutils .single-left-divider { border-left-width: 2px; }
table.docutils th + .single-left-divider,
table.docutils th + .double-left-divider { border-left-width: 0; }
table.docutils .double-left-divider { border-left-width: 6px; border-left-style: double; }
table.docutils .single-right-divider:last-child { border-right-width: 2px; }
table.docutils .double-right-divider:last-child { border-right-width: 6px; border-right-style: double; }

/*****************************************************
 * document - field-list tables & contents
 *****************************************************/
table.docutils th.field-name { background: none; }

.field-list p { margin-bottom: 16px; }

td.field-body > p.first,
td.field-body > ul.first.simple > li { margin-bottom: 1em; }

td.field-body > em,
td.field-body > ul.first.simple > li > em { padding: 2px 4px; }

td.field-body > p.first:empty { display: none; }
td.field-body > p:last-child:empty { margin-bottom: 1em; }

/* workaround for chrome bug */
td.field-body > p.first:only-child { margin: 0; }

/*****************************************************
 * document - admonitions
 *****************************************************/

   /*------------------------------------
    * basic admonition styling - adds colored bg & icons
    *------------------------------------*/

div.admonition, p.deprecated
{
   background: #E7F0FE;
   border: 1px solid rgba(0,0,0,.05);
   border-width: 0 1px 1px 0;
   margin: 1.5em;
   padding: .5em;
   
   -moz-border-radius: 0 0.7em;
   -webkit-border-radius: 0 0.7em;
   -o-border-radius: 0 0.7em;
   -ms-border-radius: 0 0.7em;
   border-radius: 0 0.7em;


   font-size: 95.0%;
}



div.admonition-todo,
p.deprecated,
div.admonition-note,
div.admonition-tip,
div.admonition-important,
div.admonition-warning,
div.admonition-seealso,
div.admonition-optional,
div.admonition-example,
div.admonition-python-example,
div.admonition-shell-example,
div.admonition-javascript-example,
div.admonition-json-example,
div.admonition-lconf-example
{
   background-position: .6em .5em;
   background-size: auto 1.58em;
   background-repeat: no-repeat;
   padding-left: 2.65em;
}



div.admonition-todo {
   background-color: #FFF7E0;
   background-image: url("icon-todo.png");
}


p.deprecated {
   background-color: #fbece0;
   background-image: url("icon-deprecated.png");
}



div.admonition-note {
   background-color: #E7F0FE;
   background-image: url("icon-note.png");
}


div.admonition-tip {
   background-color: #f8defd;
   background-image: url("icon-tip.png");
}


div.admonition-important {
   background-color: #feffd6;
   background-image: url("icon-important.png");
}


div.admonition-warning {
   background-color: #efc2c2;
   background-image: url("icon-warning.png");
}


div.admonition-seealso {
   background-color: #FFF7E0;
   background-image: url("icon-seealso.png");
}


div.admonition-optional {
   background-color: #FFFFFF;
   background-image: url("icon-optional.png");
}


div.admonition-example {
   background-color: #d1ffd6;
   background-image: url("icon-example.png");
}


div.admonition-python-example {
   background-color: #d1ffd6;
   background-image: url("icon-python-example.png");
}


div.admonition-shell-example {
   background-color: #d1ffd6;
   background-image: url("icon-shell-example.png");
}


div.admonition-javascript-example {
   background-color: #d1ffd6;
   background-image: url("icon-javascript-example.png");
}


div.admonition-json-example {
   background-color: #d1ffd6;
   background-image: url("icon-json-example.png");
}


div.admonition-lconf-example {
   background-color: #fff0c7;
   background-image: url("icon-lconf-example.png");
}



   /*------------------------------------
    * misc adjustments to admonitions
    *------------------------------------*/

div.admonition p,
div.admonition pre,
div.admonition ul,
div.admonition ol { margin-bottom: 5px; }

/* allow div.admonition to float on right side w/in document */
div.admonition.floater
{
   float: right;
   max-width: 40%;
   margin: 1em 0 1.5em 1.5em;
}


   /* next few rules merge the title into the first paragraph */
p.admonition-title { display: inline; margin-right: 0; }
p.admonition-title + p { display: inline; }
p.admonition-title:after { content: ":"; }
p.admonition-title + ul { margin-top: 0; }



/* don't indent admonitions inside definitions */
dl div.admonition { margin-left: 0; }

   /*------------------------------------
    * todo summary list
    *------------------------------------*/

div#todos p.admonition-title
{
   font-weight: normal;
   color: #AAA;
   font-size: 70%;
}

div#todos div.admonition-todo + p
{
   font-size: 70%;
   text-align: right;
   margin-top: -.5em;
   margin-bottom: 1.5em;
   color: #AAA;
}

div#todos div.admonition-todo + p a
{
   font-size: 130%;
}

/*****************************************************
 * document - verionchanged/modified/deprecated
 *****************************************************/
div.deprecated, div.versionchanged, div.versionadded
{
   font-size: 95.0%;
   filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=0.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.60.6);
 opacity: 0.6;
;
}


span.versionmodified
{
   font-weight: bold;
}

/*****************************************************
 * document - quoted text / code blocks (TT & PRE)
 *****************************************************/

div.highlight
{
   background: none;
}

div.highlight pre,
div.highlight-python pre,
div.highlight-python3 pre
{
   padding: 10px;

   background-color: #eeffcc;
   border: 1px solid #AACC99;
/*   border-width: 0 4px;
   
   -moz-border-radius: 8px;
   -webkit-border-radius: 8px;
   -o-border-radius: 8px;
   -ms-border-radius: 8px;
   border-radius: 8px;

*/
   border-width: 1px 0;

   font-family: "Source Code Pro";
   font-size: 90%;
   line-height: 1.5em;

   color: #111111;
}

/* for source-view pages */
div.body > h1 + div.highlight:last-child > pre
{
   padding-top: 5em;
   margin-top: -5em;
   margin-bottom: -10px;
}

table.highlighttable td { padding: 0; }
table.highlighttable td.code { width: 100%; }
table.highlighttable div.linenodiv pre
{
   background: none;
   border: 0;
   margin: 0;
   padding: 0;
   padding-right: .5em;
   filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=30.0);
 opacity: 0.3;

}

tt
{
   font-family: "Droid Sans Mono";
   font-size: 90%;
}

tt.literal
{
   background-color: rgba(0,0,0,.075);
   border: 1px solid rgba(0,0,0,.05);
   padding: 0px 4px;
   margin: 1px;

   
   -moz-border-radius: 4px;
   -webkit-border-radius: 4px;
   -o-border-radius: 4px;
   -ms-border-radius: 4px;
   border-radius: 4px;


}

p tt.literal { white-space: nowrap; }

tt.samp.literal > em
{
   font-family: "Noticia Text";
   padding: 0 1px;
   filter: progid:DXImageTransform.Microsoft.Alpha(Opacity=60.0);
 opacity: 0.6;

}

tt.samp.literal > em:before { content: "{"; }
tt.samp.literal > em:after { content: "}"; }

h1 tt.literal
{
   background-color: inherit;
   border: 0;
   font-size: 80%;
}

h1 tt.samp.literal > em
{
   font-weight: normal;
}

div.sphinxsidebar tt.literal,
a.reference tt.literal,
div.related a tt.literal,
tt.literal.xref
{
   background-color: transparent;
   border: none;
   padding: 0;
   margin: 0;
}

.viewcode-back
{
   font-family: "Noto Sans";
}

div.viewcode-block:target
{
   background-color: #f4debf;
   border-top: 1px solid #ac9;
   border-bottom: 1px solid #ac9;
}

/*****************************************************
 * index page styling
 * requires classes set by .ext.index_styling
 *****************************************************/

table.indextable span.category
{
   font-size: 80%;
   font-style: italic;
   color: #84ADBE;
}

table.indextable a,
table.indextable a:hover span.category
{
   color: #003469;
}

table.indextable span.category span.location
{
   font-weight: bold;
}

table.indextable td > dl > dt
{
   margin-bottom: .5em;
}

table.indextable td > dl > dd > dl
{
   margin-top: -.5em;
   margin-bottom: .5em;
}

/*****************************************************
 * adapt for various page sizes & media
 *****************************************************/

/*------------------------------------
 * adapt for larger displays
 *------------------------------------*/
@media only screen and (min-device-width: 16in)
{
   body { font-size: 87.5%; }
}

/*------------------------------------
 * adapt for 'compact' and 'minimal' page sizes
 *------------------------------------*/

@media only screen and (max-width: 960px),
       only screen and (max-width: 700px),
       only screen and (max-device-width: 700px),
       handheld
{
   body { margin: 0; }

   div.relbar-top div.related,
   div.relbar-bottom div.related
   {
       
   -moz-border-radius: 0;
   -webkit-border-radius: 0;
   -o-border-radius: 0;
   -ms-border-radius: 0;
   border-radius: 0;


   }

   /* hide extra info */
   div.admonition.floater { display: none; }
}

/*------------------------------------
 * adapt for 'minimal' page size
 *------------------------------------*/
@media only screen and (max-width: 700px),
       only screen and (max-device-width: 700px),
       handheld
{
   body { font-size: 87.5%; }

   /* hide the sidebar */
   div.sphinxsidebar
   {
      display: none;
   }

   
    /* FIXME: would like to make this work some how, hiding it til it works */
      div.sidebartoggle { display: none; }
   

   div.bodywrapper
   {
      margin-left: 0;
   }

   /* tweak relbar - emphasize title, hide crumbs */
   div.related > ul > li.right + li:not(.right) { font-weight: bold; }
   div.related > ul > li:not(.right) + li { display: none; }

   /* remove spacing on headers and reduce body padding */
   body div.body h2,
   body div.body p.rubric,
   /*body div.section.emphasized > h3,  deprecated in favor of below: */
   body div.section.emphasize-children > div.section > h3
   {
      padding-top: 0.25em;
      padding-bottom: .25em;
      
   -moz-border-radius: 0;
   -webkit-border-radius: 0;
   -o-border-radius: 0;
   -ms-border-radius: 0;
   border-radius: 0;


   }

   /* shrink the headers */
   div.body h1 { font-size: 160%; }
   div.body h2, div.body p.rubric { font-size: 140%; }
   div.body h3 { font-size: 120%; }
   div.body h4 { font-size: 110%; }
   div.body h5 { font-size: 100%; }
}

/*------------------------------------
 * adapt for print media
 *------------------------------------*/

@media print
{
   div.sidebartoggle { display: none; }
   div.body { border: 0; }

   /* omit "hide section" label */
   .html-toggle.expanded > .html-toggle-button:after
   {
      display: none;
   }

   /* indicate collapsed sections were omitted
       TODO: would like to auto-expand them instead, but not sure how to
       create a reliable CSS rule given the way the JS code currently works.
    */
   .html-toggle.collapsed > .html-toggle-button:after
   {
      content: "[not printed]";
   }

   /* remove styling from headers */
   div.body h1,
   div.body h2,
   div.body p.rubric,
   div.body h3,
   div.body h4,
   div.body h5,
   div.body h6
   {
      color: #000000;
      text-shadow: none;
      border: none;
      padding: 0;
   }
}






/*****************************************************
 * DOCSTRING: code line  parts
 * descclassname / descname
 *****************************************************/

tt.descclassname {
   background-color: transparent;
   font-weight: normal;
   font-size: 1.1em;
}

tt.descname {
   background-color: rgba(242, 242, 242, 0.5);
   font-weight: normal;
   font-size: 1.2em;
}


/*****************************************************
 * EOF
 *****************************************************/